import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ValidatedService")


@attr.s(auto_attribs=True, repr=False)
class ValidatedService:
    """
    Attributes:
        ref (Union[Unset, str]):  Default: ''.
        service_validated (Union[Unset, bool]):  Default: True.
        sha (Union[Unset, str]):  Default: ''.
        type (Union[Unset, str]):  Default: ''.
    """

    ref: Union[Unset, str] = ""
    service_validated: Union[Unset, bool] = True
    sha: Union[Unset, str] = ""
    type: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ref = self.ref
        service_validated = self.service_validated
        sha = self.sha
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ref is not UNSET:
            field_dict["ref"] = ref
        if service_validated is not UNSET:
            field_dict["service_validated"] = service_validated
        if sha is not UNSET:
            field_dict["sha"] = sha
        if type is not UNSET:
            field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        ref = d.pop("ref", UNSET)

        service_validated = d.pop("service_validated", UNSET)

        sha = d.pop("sha", UNSET)

        type = d.pop("type", UNSET)

        validated_service = cls(
            ref=ref,
            service_validated=service_validated,
            sha=sha,
            type=type,
        )

        validated_service.additional_properties = d
        return validated_service

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import os

import typer
from rich.text import Text

from oblv_ctl import __version__, authenticate

from . import deployment, service, utils

app = typer.Typer(no_args_is_help=True, rich_markup_mode="markdown", help="""**Oblvious Controller v{}**   
**Oblivious Software Ltd. <oblivious.ai>**  
======
  
__Description__  

---

The Oblivious Controller is a command line tool to manage your Oblivious services.
 """.format(__version__),add_completion=False)


@app.command(help="Command to login to oblv")
def login(apikey: str):
    if apikey=="":
        apikey = typer.prompt("Kindly provide your api key ")
    try:
        client = authenticate(apikey)
        credentials = "oblivious_user_id = {}\ntoken = {}".format(client.oblivious_user_id,client.token)
        os.makedirs(os.path.dirname(utils.cred_file_path), exist_ok=True)
        with open(utils.cred_file_path,'w') as f:
            f.write(credentials)
    except Exception as e:
        print(e)
    else:
        print("Successfully logged in")
        
@app.command(help="Command to clear and invalidate the token")
def logout():
    try:
        if os.path.exists(utils.cred_file_path):
            with open(utils.cred_file_path,'w') as f:
                #Just overwriting the file, whether login exists or not
                f.write("")
    except FileNotFoundError as e:
        #Case where .oblv folder was never generated
        #With the check of path exists makes no sense
        print(".oblv folder not found")
    except Exception as e:
        print(e)
    else:
        print("Successfully logged out")
    
@app.command(help="Command to fetch the VCS accounts")
def accounts():
    try:
        client = utils.read_credentials()
        # console.print("["+",\n".join([x.__repr__() for x in client.accounts()])+"]")
        utils.render_output(client.accounts())
    except FileNotFoundError as e:
        print("Kindly login before performing this action")
    except Exception as e:
        print(e)
    
@app.command(help="Command to fetch/set the Public Key")
def psk(set_key : str = typer.Option(None, help="Public key to be set")):
    try:
        client = utils.read_credentials()
        if set_key!=None:
            client.set_psk(set_key)
        else:
            utils.render_output(client.psk())
    except FileNotFoundError as e:
        print("Kindly login before performing this action")
    except Exception as e:
        print(e)
    
app.add_typer(service.app, name="service", help="Commands to interact with the services")
app.add_typer(deployment.app, name="deployment", help="Commands to interact with the deployments")



if __name__ == "__main__":
    app()



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.validated_service import ValidatedService
from ..types import UNSET, Unset

T = TypeVar("T", bound="ServiceValidationResponse")


@attr.s(auto_attribs=True, repr=False)
class ServiceValidationResponse:
    """
    Attributes:
        message (Union[Unset, str]):  Default: ''.
        service (Union[Unset, ValidatedService]):
    """

    message: Union[Unset, str] = ""
    service: Union[Unset, ValidatedService] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message
        service: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.service, Unset):
            service = self.service.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if message is not UNSET:
            field_dict["message"] = message
        if service is not UNSET:
            field_dict["service"] = service

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        message = d.pop("message", UNSET)

        _service = d.pop("service", UNSET)
        service: Union[Unset, ValidatedService]
        if isinstance(_service, Unset):
            service = UNSET
        else:
            service = ValidatedService.from_dict(_service)

        service_validation_response = cls(
            message=message,
            service=service,
        )

        service_validation_response.additional_properties = d
        return service_validation_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BuildArgsSchema")


@attr.s(auto_attribs=True, repr=False)
class BuildArgsSchema:
    """
    Attributes:
        sha (Union[Unset, str]):  Default: ''.
        arg_schema (Union[Unset, Any]):
    """

    sha: Union[Unset, str] = ""
    arg_schema: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sha = self.sha
        arg_schema = self.arg_schema

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sha is not UNSET:
            field_dict["sha"] = sha
        if arg_schema is not UNSET:
            field_dict["arg_schema"] = arg_schema

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sha = d.pop("sha", UNSET)

        arg_schema = d.pop("arg_schema", UNSET)

        build_args_schema = cls(
            sha=sha,
            arg_schema=arg_schema,
        )

        build_args_schema.additional_properties = d
        return build_args_schema

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateDeploymentInput")


@attr.s(auto_attribs=True, repr=False)
class CreateDeploymentInput:
    """
    Attributes:
        owner (str): Repository Owner
        repo (str): Repository Name
        account_type (str): VCS Account (Only 'github' supported as of now)
        ref (str): Service ref
        ref_type (str): Service ref type
        region_name (str): AWS supported region the deployment must be deployed in.
        deployment_name (str): Deployment Name
        is_dev_env (bool): Deployment Environment
        tags (List[str]): Deployment Tags
        build_args (Any): Deployment build args
        visibility (Union[Unset, str]): Deployment Visibility Default: 'private'.
    """

    owner: str
    repo: str
    account_type: str
    ref: str
    ref_type: str
    region_name: str
    deployment_name: str
    is_dev_env: bool
    tags: List[str]
    build_args: Any
    visibility: Union[Unset, str] = "private"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        owner = self.owner
        repo = self.repo
        account_type = self.account_type
        ref = self.ref
        ref_type = self.ref_type
        region_name = self.region_name
        deployment_name = self.deployment_name
        is_dev_env = self.is_dev_env
        tags = self.tags

        build_args = self.build_args
        visibility = self.visibility

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "owner": owner,
                "repo": repo,
                "account_type": account_type,
                "ref": ref,
                "ref_type": ref_type,
                "region_name": region_name,
                "deployment_name": deployment_name,
                "is_dev_env": is_dev_env,
                "tags": tags,
                "build_args": build_args,
            }
        )
        if visibility is not UNSET:
            field_dict["visibility"] = visibility

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        owner = d.pop("owner")

        repo = d.pop("repo")

        account_type = d.pop("account_type")

        ref = d.pop("ref")

        ref_type = d.pop("ref_type")

        region_name = d.pop("region_name")

        deployment_name = d.pop("deployment_name")

        is_dev_env = d.pop("is_dev_env")

        tags = cast(List[str], d.pop("tags"))

        build_args = d.pop("build_args")

        visibility = d.pop("visibility", UNSET)

        create_deployment_input = cls(
            owner=owner,
            repo=repo,
            account_type=account_type,
            ref=ref,
            ref_type=ref_type,
            region_name=region_name,
            deployment_name=deployment_name,
            is_dev_env=is_dev_env,
            tags=tags,
            build_args=build_args,
            visibility=visibility,
        )

        create_deployment_input.additional_properties = d
        return create_deployment_input

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Repo")


@attr.s(auto_attribs=True, repr=False)
class Repo:
    """
    Attributes:
        repo_id (Union[Unset, str]):  Default: ''.
        name (Union[Unset, str]):  Default: ''.
        full_name (Union[Unset, str]):  Default: ''.
        is_private (Union[Unset, bool]):
        owner_login (Union[Unset, str]):  Default: ''.
        description (Union[Unset, str]):  Default: ''.
        html_url (Union[Unset, str]):  Default: ''.
        git_url (Union[Unset, str]):  Default: ''.
        clone_url (Union[Unset, str]):  Default: ''.
        default_branch (Union[Unset, str]):  Default: ''.
        updated_at (Union[Unset, str]):  Default: ''.
        account_type (Union[Unset, str]):  Default: 'github'.
    """

    repo_id: Union[Unset, str] = ""
    name: Union[Unset, str] = ""
    full_name: Union[Unset, str] = ""
    is_private: Union[Unset, bool] = False
    owner_login: Union[Unset, str] = ""
    description: Union[Unset, str] = ""
    html_url: Union[Unset, str] = ""
    git_url: Union[Unset, str] = ""
    clone_url: Union[Unset, str] = ""
    default_branch: Union[Unset, str] = ""
    updated_at: Union[Unset, str] = ""
    account_type: Union[Unset, str] = "github"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        repo_id = self.repo_id
        name = self.name
        full_name = self.full_name
        is_private = self.is_private
        owner_login = self.owner_login
        description = self.description
        html_url = self.html_url
        git_url = self.git_url
        clone_url = self.clone_url
        default_branch = self.default_branch
        updated_at = self.updated_at
        account_type = self.account_type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if repo_id is not UNSET:
            field_dict["repo_id"] = repo_id
        if name is not UNSET:
            field_dict["name"] = name
        if full_name is not UNSET:
            field_dict["full_name"] = full_name
        if is_private is not UNSET:
            field_dict["is_private"] = is_private
        if owner_login is not UNSET:
            field_dict["owner_login"] = owner_login
        if description is not UNSET:
            field_dict["description"] = description
        if html_url is not UNSET:
            field_dict["html_url"] = html_url
        if git_url is not UNSET:
            field_dict["git_url"] = git_url
        if clone_url is not UNSET:
            field_dict["clone_url"] = clone_url
        if default_branch is not UNSET:
            field_dict["default_branch"] = default_branch
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if account_type is not UNSET:
            field_dict["account_type"] = account_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        repo_id = d.pop("repo_id", UNSET)

        name = d.pop("name", UNSET)

        full_name = d.pop("full_name", UNSET)

        is_private = d.pop("is_private", UNSET)

        owner_login = d.pop("owner_login", UNSET)

        description = d.pop("description", UNSET)

        html_url = d.pop("html_url", UNSET)

        git_url = d.pop("git_url", UNSET)

        clone_url = d.pop("clone_url", UNSET)

        default_branch = d.pop("default_branch", UNSET)

        updated_at = d.pop("updated_at", UNSET)

        account_type = d.pop("account_type", UNSET)

        repo = cls(
            repo_id=repo_id,
            name=name,
            full_name=full_name,
            is_private=is_private,
            owner_login=owner_login,
            description=description,
            html_url=html_url,
            git_url=git_url,
            clone_url=clone_url,
            default_branch=default_branch,
            updated_at=updated_at,
            account_type=account_type,
        )

        repo.additional_properties = d
        return repo

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import unittest
from http.client import FORBIDDEN
from unittest.mock import patch

from httpx import Response

from oblv_ctl.exceptions import BadRequestError, HTTPClientError, ParamValidationError, UnauthorizedTokenError
from oblv_ctl.models.http_validation_error import HTTPValidationError
from oblv_ctl.models.service_validation_response import ServiceValidationResponse
from oblv_ctl.models.validation_error import ValidationError
from oblv_ctl.oblv_client import OblvClient
from tests.unit.constants import (
    API_GW_REQUEST_ID,
    BAD_REQUEST_MESSAGE,
    EXCEPTION_OCCURED,
    INVALID_PUBLIC_KEY,
    KEY_APIGW_REQUESTID,
    KEY_MESSAGE,
    KEY_VALID_ERROR_LOC,
    RANDOM_PUBLIC_KEY,
    REPO_SERVICES,
    SERVICE_YAML_CONTENT,
    SUCCESS,
    USER_ID,
    USER_TOKEN,
    VALID_ERROR_MESSAGE,
    VALID_ERROR_VALUE,
)


class TestAddService(unittest.TestCase):

    client = OblvClient(token=USER_TOKEN,oblivious_user_id=USER_ID)
    
    def setUp(self) -> None:
        super().setUp()

    def getBadRequestResponse():
        res = Response(400, json={KEY_MESSAGE: BAD_REQUEST_MESSAGE})
        return res

    def getHTTPExceptionResponse():
        res = Response(500, json={KEY_MESSAGE: EXCEPTION_OCCURED}, headers={
                       KEY_APIGW_REQUESTID: API_GW_REQUEST_ID})
        return res

    def getFailedValidationResponse():
        data = HTTPValidationError(
            [ValidationError([KEY_VALID_ERROR_LOC], VALID_ERROR_MESSAGE, VALID_ERROR_VALUE)])
        res = Response(422, json=data.to_dict())
        return res
    
    def getForbiddenResponse():
        res = Response(403, json=FORBIDDEN)
        return res

    def getSuccessResponse():
        res = Response(200, json={KEY_MESSAGE: SUCCESS, "service": REPO_SERVICES[0]})
        return res

    @patch("httpx.request", return_value=getBadRequestResponse())
    def test_bad_request(self, sync):
        with self.assertRaises(BadRequestError) as cm:
            self.client.update_service(ref="master",repo_id="123456")

    @patch("httpx.request", return_value=getHTTPExceptionResponse())
    def test_http_exception_request(self, sync):
        with self.assertRaises(HTTPClientError) as cm:
            self.client.update_service(ref="master",repo_id="123456")

    @patch("httpx.request", return_value=getFailedValidationResponse())
    def test_failed_validation_request(self, sync):
        with self.assertRaises(ParamValidationError) as cm:
            self.client.update_service(ref="master",repo_id="123456")

        the_exception = cm.exception
        self.assertEqual(the_exception.__str__(), "Invalid {} provided".format(KEY_VALID_ERROR_LOC))

    @patch("httpx.request", return_value=getForbiddenResponse())
    def test_bad_authentication_request(self, sync):
        with self.assertRaises(UnauthorizedTokenError):
            self.client.update_service(ref="master",repo_id="123456")

    @patch("httpx.request", return_value=getSuccessResponse())
    def test_success_request(self, sync):
        obj = ServiceValidationResponse.from_dict({KEY_MESSAGE: SUCCESS, "service": REPO_SERVICES[0]})
        self.assertEqual(self.client.update_service(ref="master",repo_id="123456",repo_name="Repo_Name",repo_owner="Owner_Name"),obj)
        self.assertEqual(self.client.update_service(ref="master",repo_name="Repo_Name",repo_owner="Owner_Name"),obj)
        self.assertEqual(self.client.update_service(ref="master",repo_id="123456"),obj)
        self.assertEqual(self.client.update_service(ref="master",repo_id="123456",data=SERVICE_YAML_CONTENT),obj)
        with self.assertRaises(BadRequestError):
            self.client.update_service(ref="master")


if __name__ == '__main__':
    unittest.main()



import requests
import sys
from jsonschema import validate
from jsonschema.exceptions import ValidationError
from oblv_ctl.models.name_input import NameInput
from .api.account import get_user_accounts_account_get
from .api.auth import logout_session_logout_delete
from .api.deployment import (
    create_new_deployment_deployment_post,
    delete_deployment_deployment_delete,
    generate_build_args_deployment_arguments_get,
    get_available_deployments_deployment_available_get,
    get_deployment_info_deployment_get,
    get_deployment_roles_deployment_roles_get,
    get_supported_regions_deployment_supported_regions_get,
    get_user_owned_deployments_deployment_owned_get,
)
from .api.repo import (
    get_all_repos_repo_linked_get,
    get_repo_from_vcs_repo_get,
    get_repo_refs_repo_refs_get,
    get_repo_repo_repo_owner_repo_name_get,
    search_repo_from_vcs_repo_search_get,
)
from .api.service import (
    add_repo_service_repo_service_post,
    delete_repo_services_repo_service_delete,
    get_repo_service_yaml_form_content_repo_service_yaml_get,
    get_repo_services_repo_service_get,
    get_user_services_service_get,
    update_repo_service_repo_service_put,
    validate_repo_service_repo_service_validate_get,
)
from .api.user import (
    add_user_public_shared_key_user_psk_put,
    get_user_deployment_credit_usage_user_credit_usage_get,
    get_user_profile_view_user_profile_get,
    get_user_public_shared_key_user_psk_get,
    update_user_name_user_name_put,
    update_user_password_user_password_put,
)
from .client import AuthenticatedClient
from .config import URL
from .exceptions import BadYamlData
from .models import (
    PSK,
    CreateDeploymentInput,
    ServiceYamlAddInput,
    ServiceYamlUpdateInput,
    UserPasswordInput,
)
from .utils import bcolors


class OblvClient(AuthenticatedClient):
    def _method_wrapper(function):
        def wrap(*args, **kwargs):
            try:
                return function(*args, **kwargs)
            except Exception as e:
                reason = e.__str__()
                print(
                bcolors.RED
                + bcolors.BOLD
                + "Exception"
                + bcolors.BLACK
                + bcolors.ENDC
                + f": {e}",
                file=sys.stderr,
            )
                raise Exception(reason)

        return wrap

    @_method_wrapper
    def logout(self):
        """Logout Session

         This API invalidates the user's token. After a successul response, the user will not be able to use
        the auth token provided in the auth APIs.

        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel]]
        """
        try:
            logout_session_logout_delete.sync(
                client=self, oblivious_user_id=self.oblivious_user_id
            )
        except Exception as e:
            raise e
        finally:
            self.token = ""
            self.oblivious_user_id = ""

    ###### Account Method ######

    @_method_wrapper
    def accounts(self):
        """Get User Accounts
         API to fetch user's linked VCS accounts
        Returns:
            Response[Union[Any, HTTPValidationError, List[Account], MessageModel]]
        """
        return get_user_accounts_account_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    ############################

    ####### User Methods #######
    @_method_wrapper
    def psk(self):
        """Get User PSK
         API to fetch user's psk
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, str]]
        """
        return get_user_public_shared_key_user_psk_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            user_id=self.oblivious_user_id,
        )

    @_method_wrapper
    def credit_usage(self):
        """Get User Credit Usage
         API to fetch user's credit usage
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, UserCreditUtilization]]
        """
        return get_user_deployment_credit_usage_user_credit_usage_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    @_method_wrapper
    def set_psk(self, public_key):
        """Update user's publically shareable key
        API to update user's publically shareable key
        Args:
            public_key (str): Public Key to be shared
        Returns:
            Response[Union[None, HTTPValidationError, MessageModel]]
            None is returned if successful
        """

        input = PSK(public_key)
        return add_user_public_shared_key_user_psk_put.sync(
            client=self, oblivious_user_id=self.oblivious_user_id, json_body=input
        )

    @_method_wrapper
    def update_name(self, name):
        """Update Name
        API to update the name.
        Args:
            name (str): User Name
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel]]
        """
        update_user_name_user_name_put.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            json_body=NameInput(name),
        )
        print("Name updated successfully")

    @_method_wrapper
    def update_password(self, old_pass, new_pass):
        """Update User's Password
         API to update user's password
        Args:
            old_pass (str): Old Password
            new_pass (str): New Password
        Returns:
            Response[Union[None, HTTPValidationError, MessageModel]]
                None is returned if successful
        """
        input = UserPasswordInput(old_password=old_pass, password=new_pass)
        update_user_password_user_password_put.sync(
            client=self, oblivious_user_id=self.oblivious_user_id, json_body=input
        )
        print("Password updated successfully")

    @_method_wrapper
    def user_profile(self):
        """Get User Profile
         API to fetch user's profile details
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, UserProfileResponse]]
        """
        return get_user_profile_view_user_profile_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    ############################

    ####### Repo Methods #######
    @_method_wrapper
    def get_repo(self, owner, name):
        """Get User Repo
         API to fetch user's repo information
        Args:
            owner (str): Repo Owner
            name (str): Repo Name
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, Repo]]
        """
        return get_repo_repo_repo_owner_repo_name_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo_owner=owner,
            repo_name=name,
        )

    @_method_wrapper
    def search_repo(self, keyword):
        """Add Repo Service With Yaml
         API to search a repository in VCS, on which the user has access (via their own account, or by any
        organization they are member of).
        Args:
            keyword (str): Search Keyword
        Returns:
            Response[Union[Any, HTTPValidationError, List[Repo], MessageModel]]
        """
        return search_repo_from_vcs_repo_search_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id, search_string=keyword
        )

    @_method_wrapper
    def linked_repos(self):
        """Get User Repos
         API to fetch user's repo without services
        Returns:
            Response[Union[Any, HTTPValidationError, List[RepoAllResponse], MessageModel]]
        """
        return get_all_repos_repo_linked_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    @_method_wrapper
    def repo_refs(self, owner, name):
        """Get Repo Refs
         API to fetch the repository refs (branches and tags).
        Args:
            owner (str): Repo Owner
            name (str): Repo Name
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, RefResponse]]
        """
        return get_repo_refs_repo_refs_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo_owner=owner,
            repo_name=name,
        )

    @_method_wrapper
    def repos(self, page: int = 1, per_page: int = 10):
        """Get Repos From VCS
         API to get all the repositories from VCS, on which the user has access (via their own account, or by
        any organization they are member of).
        Args:
            page (int):  Page (Default 1)
            per_page (int):  Repositiories Per Page (Default 10)
        Returns:
            Response[Union[Any, HTTPValidationError, VCSRepoResponse]]
        """
        return get_repo_from_vcs_repo_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            page=page,
            per_page=per_page,
        )

    ############################

    ##### Services Methods #####
    @_method_wrapper
    def add_service(
        self,
        repo_owner: str,
        repo_name: str,
        ref: str,
        ref_type: str = "branch",
        data: dict = {},
    ):
        """Add Repo Service
         API to create a service after validation.
        Args:
            repo_owner (str): Repo's Owner Name
            repo_name (str): Repo Name
            ref (str): Service Ref
            ref_type (Union[Unset, None, str]):  Ref Type branch/tag (Default 'branch')
            data (dict): Service Yaml Content in dictionary format. If provided, service.yaml file will be created/updated based on its existence.
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, ServiceValidationResponse]]
        """
        if data != {}:
            try:
                req = requests.get(URL + "/service_schema")
                if req.status_code != 200:
                    raise Exception("Failed to validate service yaml data")
                validate(data, req.json())
            except ValidationError as e:
                raise BadYamlData(e.message)
            except Exception as e:
                raise e
        input = ServiceYamlAddInput.from_dict(data)
        return add_repo_service_repo_service_post.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            ref=ref,
            ref_type=ref_type,
            repo_owner=repo_owner,
            repo_name=repo_name,
            json_body=input,
        )

    @_method_wrapper
    def remove_service(
        self, repo_owner: str, repo_name: str, ref: str, ref_type: str = "branch"
    ):
        """Delete Repo Service
         API to delete a service. It does not delete the existing deployments created from this service.
        Args:
            repo_owner (str): Repo's Owner Name
            repo_name (str): Repo Name
            ref (str): Service Ref
            ref_type (Union[Unset, None, str]):  Ref Type branch/tag (Default 'branch')
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel]]
        """
        delete_repo_services_repo_service_delete.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            ref=ref,
            ref_type=ref_type,
            repo_name=repo_name,
            repo_owner=repo_owner,
        )
        print("Successfully removed service")

    @_method_wrapper
    def service_content(
        self, repo_owner: str, repo_name: str, ref: str, ref_type: str = "branch"
    ):
        """Get Repo Service Yaml
         API to fetch the service.yaml content as object for the given service.
        Args:
            repo_id (Union[Unset, str]): Repo Id
            ref (str): Service Ref
            ref_type (Union[Unset, None, str]):  Ref Type branch/tag (Default 'branch')
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, ServiceContentResponse]]
        """
        return get_repo_service_yaml_form_content_repo_service_yaml_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo_owner=repo_owner,
            repo_name=repo_name,
            ref=ref,
            ref_type=ref_type,
        )

    @_method_wrapper
    def repo_services(
        self,
        repo_owner: str,
        repo_name: str,
        page: int = 1,
        per_page: int = 10,
        get_all: bool = False,
    ):
        """Get Repo Services
         API to fetch all the services available for the given repository. This API is valid only for linked
        repositories.
        Args:
            repo_id (str): Repo Id
        Returns:
            Response[Union[Any, HTTPValidationError, List[ValidatedService], MessageModel]]
        """
        return get_repo_services_repo_service_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo_owner=repo_owner,
            repo_name=repo_name,
            page=page,
            per_page=per_page,
            get_all=get_all,
        )

    @_method_wrapper
    def user_services(
        self,
        page: int = 1,
        per_page: int = 10,
        get_all: bool = False,
        search_keyword: str = "",
    ):
        """Get User Services
         API to fetch user's services
        Args:
            page (int):  Page (Default 1)
            per_page (str): services per page (Default 10)
            search_keyword (str): Search Keyword and is applied on repo full name (Default "")
            get_all (bool): To fetch all services at once (Default False)

        Returns:
            Response[Union[Any, HTTPValidationError, List[UserServices], MessageModel]]
        """
        return get_user_services_service_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            page=page,
            per_page=per_page,
            get_all=get_all,
            search_term=search_keyword,
        )

    @_method_wrapper
    def update_service(
        self,
        repo_owner: str,
        repo_name: str,
        ref,
        ref_type: str = "branch",
        data: dict = {},
    ):
        """Update Repo Service With Yaml
         API to update a service, along with updating the service.yaml file. After updating the service.yaml file, the service is validate as well (for missing Dockerfile).
        Args:
            repo_owner (str): Repo's Owner Name
            repo_name (str): Repo Name
            ref (str): Service Ref
            ref_type (Union[Unset, None, str]):  Ref Type branch/tag (Default 'branch')
            data (dict): Service Yaml Content in dictionary format. If provided, service.yaml file will be created/updated based on its existence.

        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, ServiceValidationResponse]]
        """
        if data != {}:
            try:
                req = requests.get(URL + "/service_schema")
                if req.status_code != 200:
                    raise Exception("Failed to validate service yaml data")
                validate(data, req.json())
            except ValidationError as e:
                raise BadYamlData(e.message)
            except Exception as e:
                raise e
        input = ServiceYamlUpdateInput.from_dict(data)
        return update_repo_service_repo_service_put.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            ref=ref,
            ref_type=ref_type,
            repo_owner=repo_owner,
            repo_name=repo_name,
            json_body=input,
        )

    @_method_wrapper
    def revalidate_service(
        self, repo_owner: str, repo_name: str, ref: str, ref_type: str = "branch"
    ):
        """Validate Repo Service
         API to validate a service with supported service schema. The checks include
        - Presence of service.yaml in ./oblivious folder.
        - Presence of Dockerfile in ./oblivious folder.
        - Content of service.yaml must be valid with respect to supported service schema.
        Args:
            repo_owner (str): Repo's Owner Name
            repo_name (str): Repo Name
            ref (str): Service Ref
            ref_type (Union[Unset, None, str]):  Ref Type branch/tag (Default 'branch')
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel, ServiceValidationResponse]]
        """
        return validate_repo_service_repo_service_validate_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo_owner=repo_owner,
            repo_name=repo_name,
            ref=ref,
            ref_type=ref_type,
        )

    ############################

    #### Deployment Methods ####

    @_method_wrapper
    def deployment_info(self, deployment_id):
        """Get Deployment
         API to fetch a deployment's details.
        Args:
            deployment_id (str): Deployment Id
        Returns:
            Response[Union[Any, DeploymentResponse, HTTPValidationError, MessageModel]]
        """
        return get_deployment_info_deployment_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            deployment_id=deployment_id,
        )

    @_method_wrapper
    def create_deployment(self, deployment: CreateDeploymentInput):
        """Create Deployment
         API to create a new deployment.
        Args:
            deployment (CreateDeploymentInput): Deployment Details Input
        Returns:
            Response[Union[Any, CreateDeploymentResponse, HTTPValidationError, MessageModel]]
        """
        return create_new_deployment_deployment_post.sync(
            client=self, oblivious_user_id=self.oblivious_user_id, json_body=deployment
        )

    @_method_wrapper
    def remove_deployment(self, deployment_id):
        """Delete Deployment
         API to initiate termination of a deployment.
        Args:
            deployment_id (str): Deployment Id
        Returns:
            Response[Union[Any, HTTPValidationError, MessageModel]]
        """
        return delete_deployment_deployment_delete.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            deployment_id=deployment_id,
        )

    @_method_wrapper
    def generate_deployment_build_args(
        self, owner: str, repo: str, ref: str, ref_type: str = "branch"
    ):
        """Get Build Deployment Arguments
        API to fetch the arguments schema necessary for creating a deployment. It also gives the commit sha,
        at which point it was generated. This is to be passed to the create deployment API.
        Note - A service could have different build args schema depending on the service's commit history.
        Args:
            owner (str): Repo Owner
            repo (str): Repo Name
            ref (str): Service Ref
            ref_type (str): Ref Type branch/tag (Default 'branch')
        Returns:
            Response[Union[Any, BuildArgsSchema, HTTPValidationError, MessageModel]]
        """
        return generate_build_args_deployment_arguments_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            repo=repo,
            owner=owner,
            ref=ref,
        )

    @_method_wrapper
    def available_deployments(self):
        """Get Available Deployments
         API to fetch all the deployments the user can connect to.
        Returns:
            Response[Union[Any, HTTPValidationError, List[DeploymentComplete], MessageModel]]
        """
        return get_available_deployments_deployment_available_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    @_method_wrapper
    def deployment_roles(self, deployment_id):
        """Get Deployment Roles
         API to get a deployment's roles.
        Args:
            deployment_id (str): Deployment Id
        Returns:
            Response[Union[Any, HTTPValidationError, List[RoleResponse], MessageModel]]
        """
        return get_deployment_roles_deployment_roles_get.sync(
            client=self,
            oblivious_user_id=self.oblivious_user_id,
            deployment_id=deployment_id,
        )

    @_method_wrapper
    def supported_aws_regions(self):
        """Deployment Supported Regions
         API to fetch a deployment's details.
        Returns:
            Response[Union[Any, MessageModel]]
        """
        return get_supported_regions_deployment_supported_regions_get.sync(client=self)

    @_method_wrapper
    def deployments(self):
        """Get Owned Deployments
         API to fetch a user's owned deployments.
        Returns:
            Response[Union[Any, HTTPValidationError, List[DeploymentResponse], MessageModel]]
        """
        return get_user_owned_deployments_deployment_owned_get.sync(
            client=self, oblivious_user_id=self.oblivious_user_id
        )

    ############################



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="OblvAuthResponse")


@attr.s(auto_attribs=True, repr=False)
class OblvAuthResponse:
    """
    Attributes:
        token (Union[Unset, str]):  Default: ''.
        user_id (Union[Unset, str]):  Default: ''.
    """

    token: Union[Unset, str] = ""
    user_id: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        token = self.token
        user_id = self.user_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if token is not UNSET:
            field_dict["token"] = token
        if user_id is not UNSET:
            field_dict["user_id"] = user_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        token = d.pop("token", UNSET)

        user_id = d.pop("user_id", UNSET)

        oblv_auth_response = cls(
            token=token,
            user_id=user_id,
        )

        oblv_auth_response.additional_properties = d
        return oblv_auth_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...exceptions import BadRequestError, HTTPClientError, ParamValidationError, UnauthorizedTokenError
from ...models.available_deployment_list import AvailableDeploymentList
from ...models.http_validation_error import HTTPValidationError
from ...models.message_model import MessageModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
    search_term: Union[Unset, None, str] = "",
) -> Dict[str, Any]:
    url = "{}/deployment/available".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["oblivious_user_id"] = oblivious_user_id

    params["page"] = page

    params["per_page"] = per_page

    params["search_term"] = search_term

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    if response.status_code == 200:
        response_200 = AvailableDeploymentList.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400_message = response.json()["message"]
        raise BadRequestError(message=response_400_message)
    if response.status_code == 500:
        response_500_request_id = response.headers["apigw-requestid"]
        raise HTTPClientError(request_id=response_500_request_id)
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())
        if response_422.detail[0].type.__contains__("regex"):
            report = "Invalid " + response_422.detail[0].loc[-1] + " provided"
        report = "Invalid " + response_422.detail[0].loc[-1] + " provided"
        raise ParamValidationError(report=report)
    if response.status_code == 403:
        raise UnauthorizedTokenError()
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
    search_term: Union[Unset, None, str] = "",
) -> Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    """Get Available Deployments

     API to fetch all the deployments the user can connect to.

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.
        search_term (Union[Unset, None, str]):  Default: ''.

    Returns:
        Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]
    """

    kwargs = _get_kwargs(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
        search_term=search_term,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
    search_term: Union[Unset, None, str] = "",
) -> Optional[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    """Get Available Deployments

     API to fetch all the deployments the user can connect to.

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.
        search_term (Union[Unset, None, str]):  Default: ''.

    Returns:
        Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]
    """

    return sync_detailed(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
        search_term=search_term,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
    search_term: Union[Unset, None, str] = "",
) -> Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    """Get Available Deployments

     API to fetch all the deployments the user can connect to.

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.
        search_term (Union[Unset, None, str]):  Default: ''.

    Returns:
        Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]
    """

    kwargs = _get_kwargs(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
        search_term=search_term,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
    search_term: Union[Unset, None, str] = "",
) -> Optional[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]:
    """Get Available Deployments

     API to fetch all the deployments the user can connect to.

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.
        search_term (Union[Unset, None, str]):  Default: ''.

    Returns:
        Response[Union[AvailableDeploymentList, HTTPValidationError, MessageModel]]
    """

    return (
        await asyncio_detailed(
            client=client,
            oblivious_user_id=oblivious_user_id,
            page=page,
            per_page=per_page,
            search_term=search_term,
        )
    ).parsed



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RepoAllResponse")


@attr.s(auto_attribs=True, repr=False)
class RepoAllResponse:
    """
    Attributes:
        name (Union[Unset, str]):  Default: ''.
        owner_login (Union[Unset, str]):  Default: ''.
        account_type (Union[Unset, str]):  Default: ''.
    """

    name: Union[Unset, str] = ""
    owner_login: Union[Unset, str] = ""
    account_type: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        owner_login = self.owner_login
        account_type = self.account_type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if owner_login is not UNSET:
            field_dict["owner_login"] = owner_login
        if account_type is not UNSET:
            field_dict["account_type"] = account_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        owner_login = d.pop("owner_login", UNSET)

        account_type = d.pop("account_type", UNSET)

        repo_all_response = cls(
            name=name,
            owner_login=owner_login,
            account_type=account_type,
        )

        repo_all_response.additional_properties = d
        return repo_all_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)




def _exception_from_packed_args(exception_cls, args=None, kwargs=None):
    # This is helpful for reducing Exceptions that only accept kwargs as
    # only positional arguments can be provided for __reduce__
    # Ideally, this would also be a class method on the OblvError
    # but instance methods cannot be pickled.
    if args is None:
        args = ()
    if kwargs is None:
        kwargs = {}
    return exception_cls(*args, **kwargs)


class OblvError(Exception):
    """
    The base exception class for Oblivious exceptions.

    :ivar msg: The descriptive message associated with the error.
    """

    fmt = 'An unspecified error occurred'

    def __init__(self, **kwargs):
        msg = self.fmt.format(**kwargs)
        Exception.__init__(self, msg)
        self.kwargs = kwargs

    def __reduce__(self):
        return _exception_from_packed_args, (self.__class__, None, self.kwargs)


class HTTPClientError(OblvError):
    fmt = 'An HTTP Client raised an unhandled exception. Kindly raise a request to the support team, along with the {request_id} for resolution.'

    def __init__(self,request_id=""):
        super().__init__(request_id=request_id)

    # def __init__(self, request=None, response=None, **kwargs):
    #     self.request = request
    #     self.response = response
    #     super().__init__(**kwargs)

    # def __reduce__(self):
    #     return _exception_from_packed_args, (
    #         self.__class__,
    #         (self.request, self.response),
    #         self.kwargs,
    #     )


class ConnectionError(OblvError):
    fmt = 'An HTTP Client failed to establish a connection: {error}'

class MissingParametersError(OblvError):
    """
    One or more required parameters were not supplied.

    :ivar object: The object that has missing parameters.
        This can be an operation or a parameter (in the
        case of inner params).  The str() of this object
        will be used so it doesn't need to implement anything
        other than str().
    :ivar missing: The names of the missing parameters.
    """

    fmt = (
        'The following required parameters are missing for '
        '{object_name}: {missing}'
    )
    
    
    def __init__(self,object_name="",missing=""):
        super().__init__(object_name=object_name,missing=missing)


class ValidationError(OblvError):
    """
    An exception occurred validating parameters.

    Subclasses must accept a ``value`` and ``param``
    argument in their ``__init__``.

    :ivar value: The value that was being validated.
    :ivar param: The parameter that failed validation.
    :ivar type_name: The name of the underlying type.
    """

    fmt = "Invalid value ('{value}') for param {param} " "of type {type_name} "
    
    def __init__(self,value="",param="",type_name=""):
        super().__init__(value=value,param=param,type_name=type_name)


class ParamValidationError(OblvError):
    fmt = '{report}'

class MissingServiceIdError(OblvError):
    fmt = (
        "The model being used for the service {service_name} is missing the "
        "serviceId metadata property, which is required."
    )

    def __init__(self, service_name):
        super().__init__(service_name=service_name)
class UnauthorizedTokenError(OblvError):
    fmt = (
        "The session associated with this profile has expired or is "
        "otherwise invalid. To refresh this session use the authenticate method "
        "with the corresponding profile."
    )

class BadRequestError(OblvError):
    fmt = '{message}'
    
    def __init__(self,message=""):
        super().__init__(message=message)
    
class AuthenticationError(OblvError):
    fmt = 'Invalid credentials provided. Kindly verify the same and try again.'


class BadYamlData(OblvError):
    fmt = 'Validation failed for service yaml data with message - {message}'
    
    
    def __init__(self,message=""):
        super().__init__(message=message)



import imp
import unittest
from http.client import FORBIDDEN
from unittest.mock import patch

from httpx import Response

from oblv_ctl.exceptions import BadRequestError, HTTPClientError, ParamValidationError, UnauthorizedTokenError
from oblv_ctl.models.account import Account
from oblv_ctl.models.http_validation_error import HTTPValidationError
from oblv_ctl.models.validation_error import ValidationError
from oblv_ctl.oblv_client import OblvClient
from tests.unit.constants import (
    API_GW_REQUEST_ID,
    BAD_REQUEST_MESSAGE,
    EXCEPTION_OCCURED,
    GITHUB,
    GITHUB_USER_ID,
    GITHUB_USER_LOGIN,
    KEY_APIGW_REQUESTID,
    KEY_MESSAGE,
    KEY_VALID_ERROR_LOC,
    USER_ID,
    USER_TOKEN,
    VALID_ERROR_MESSAGE,
    VALID_ERROR_VALUE,
)


class TestUserAccounts(unittest.TestCase):

    client = OblvClient(token=USER_TOKEN, oblivious_user_id=USER_ID)

    def setUp(self) -> None:
        super().setUp()

    def getBadRequestResponse():
        res = Response(400, json={KEY_MESSAGE: BAD_REQUEST_MESSAGE})
        return res

    def getHTTPExceptionResponse():
        res = Response(500, json={KEY_MESSAGE: EXCEPTION_OCCURED}, headers={
                       KEY_APIGW_REQUESTID: API_GW_REQUEST_ID})
        return res

    def getFailedValidationResponse():
        data = HTTPValidationError(
            [ValidationError([KEY_VALID_ERROR_LOC], VALID_ERROR_MESSAGE, VALID_ERROR_VALUE)])
        res = Response(422, json=data.to_dict())
        return res

    def getForbiddenResponse():
        res = Response(403, json=FORBIDDEN)
        return res

    def getSuccessResponse():
        res = Response(200, json=[
            {
                "user_id": GITHUB_USER_ID,
                "user_login": GITHUB_USER_LOGIN,
                "account_type": GITHUB
            }
        ])
        return res

    @patch("httpx.request", return_value=getBadRequestResponse())
    def test_bad_request(self, sync):
        with self.assertRaises(BadRequestError) as cm:
            self.client.accounts()

    @patch("httpx.request", return_value=getHTTPExceptionResponse())
    def test_http_exception_request(self, sync):
        with self.assertRaises(HTTPClientError) as cm:
            self.client.accounts()

    @patch("httpx.request", return_value=getFailedValidationResponse())
    def test_failed_validation_request(self, sync):
        with self.assertRaises(ParamValidationError) as cm:
            self.client.accounts()

        the_exception = cm.exception
        self.assertEqual(the_exception.__str__(),
                         "Invalid {} provided".format(KEY_VALID_ERROR_LOC))

    @patch("httpx.request", return_value=getForbiddenResponse())
    def test_bad_authentication_request(self, sync):
        with self.assertRaises(UnauthorizedTokenError):
            self.client.accounts()

    @patch("httpx.request", return_value=getSuccessResponse())
    def test_success_request(self, sync):
        accounts = [Account(GITHUB_USER_ID,GITHUB_USER_LOGIN,GITHUB)]
        self.assertEqual(self.client.accounts(), accounts)


if __name__ == '__main__':
    unittest.main()



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...exceptions import BadRequestError, HTTPClientError, ParamValidationError, UnauthorizedTokenError
from ...models.http_validation_error import HTTPValidationError
from ...models.vcs_repo_response import VCSRepoResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
) -> Dict[str, Any]:
    url = "{}/repo".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["oblivious_user_id"] = oblivious_user_id

    params["page"] = page

    params["per_page"] = per_page

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, HTTPValidationError, VCSRepoResponse]]:
    if response.status_code == 200:
        response_200 = VCSRepoResponse.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400_message = response.json()["message"]
        raise BadRequestError(message=response_400_message)
    if response.status_code == 500:
        response_500_request_id = response.headers["apigw-requestid"]
        raise HTTPClientError(request_id=response_500_request_id)
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())
        if response_422.detail[0].type.__contains__("regex"):
            report = "Invalid " + response_422.detail[0].loc[-1] + " provided"
        report = "Invalid " + response_422.detail[0].loc[-1] + " provided"
        raise ParamValidationError(report=report)
    if response.status_code == 403:
        raise UnauthorizedTokenError()
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HTTPValidationError, VCSRepoResponse]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
) -> Response[Union[HTTPValidationError, VCSRepoResponse]]:
    """Get Repos From VCS

     API to get all the repositories from VCS, on which the user has access (via their own account, or by
    any organization they are member of).

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.

    Returns:
        Response[Union[HTTPValidationError, VCSRepoResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
) -> Optional[Union[HTTPValidationError, VCSRepoResponse]]:
    """Get Repos From VCS

     API to get all the repositories from VCS, on which the user has access (via their own account, or by
    any organization they are member of).

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.

    Returns:
        Response[Union[HTTPValidationError, VCSRepoResponse]]
    """

    return sync_detailed(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
) -> Response[Union[HTTPValidationError, VCSRepoResponse]]:
    """Get Repos From VCS

     API to get all the repositories from VCS, on which the user has access (via their own account, or by
    any organization they are member of).

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.

    Returns:
        Response[Union[HTTPValidationError, VCSRepoResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        oblivious_user_id=oblivious_user_id,
        page=page,
        per_page=per_page,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    oblivious_user_id: str,
    page: Union[Unset, None, int] = 1,
    per_page: Union[Unset, None, int] = 10,
) -> Optional[Union[HTTPValidationError, VCSRepoResponse]]:
    """Get Repos From VCS

     API to get all the repositories from VCS, on which the user has access (via their own account, or by
    any organization they are member of).

    Args:
        oblivious_user_id (str):
        page (Union[Unset, None, int]):  Default: 1.
        per_page (Union[Unset, None, int]):  Default: 10.

    Returns:
        Response[Union[HTTPValidationError, VCSRepoResponse]]
    """

    return (
        await asyncio_detailed(
            client=client,
            oblivious_user_id=oblivious_user_id,
            page=page,
            per_page=per_page,
        )
    ).parsed



import json
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="PSK")


@attr.s(auto_attribs=True, repr=False)
class PSK:
    """
    Attributes:
        public_key (str):
    """

    public_key: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        public_key = self.public_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "public_key": public_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        public_key = d.pop("public_key")

        psk = cls(
            public_key=public_key,
        )

        psk.additional_properties = d
        return psk

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.access_history import AccessHistory
from ..models.instance import Instance
from ..models.shared_users import SharedUsers
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeploymentComplete")


@attr.s(auto_attribs=True, repr=False)
class DeploymentComplete:
    """
    Attributes:
        deployment_id (Union[Unset, str]):  Default: ''.
        deployment_name (Union[Unset, str]):  Default: ''.
        owner (Union[Unset, str]):  Default: ''.
        repo_name (Union[Unset, str]):  Default: ''.
        account_type (Union[Unset, str]):  Default: ''.
        repo_owner (Union[Unset, str]):  Default: ''.
        tags (Union[Unset, List[str]]):
        branch_release (Union[Unset, str]):  Default: ''.
        current_state (Union[Unset, str]):  Default: ''.
        visibility (Union[Unset, str]):  Default: ''.
        is_dev_env (Union[Unset, bool]):  Default: True.
        creation_time (Union[Unset, str]):  Default: ''.
        sha (Union[Unset, str]):  Default: ''.
        owner_login (Union[Unset, str]):  Default: ''.
        is_deleted (Union[Unset, bool]):
        instance (Union[Unset, Instance]):
        pcr_codes (Union[Unset, List[str]]):
        credit_utilization_per_hour (Union[Unset, float]):
        total_credits_used (Union[Unset, float]):
        build_args (Union[Unset, Any]):
        shared_users (Union[Unset, List[SharedUsers]]):
        history (Union[Unset, List[AccessHistory]]):
    """

    deployment_id: Union[Unset, str] = ""
    deployment_name: Union[Unset, str] = ""
    owner: Union[Unset, str] = ""
    repo_name: Union[Unset, str] = ""
    account_type: Union[Unset, str] = ""
    repo_owner: Union[Unset, str] = ""
    tags: Union[Unset, List[str]] = UNSET
    branch_release: Union[Unset, str] = ""
    current_state: Union[Unset, str] = ""
    visibility: Union[Unset, str] = ""
    is_dev_env: Union[Unset, bool] = True
    creation_time: Union[Unset, str] = ""
    sha: Union[Unset, str] = ""
    owner_login: Union[Unset, str] = ""
    is_deleted: Union[Unset, bool] = False
    instance: Union[Unset, Instance] = UNSET
    pcr_codes: Union[Unset, List[str]] = UNSET
    credit_utilization_per_hour: Union[Unset, float] = 0.0
    total_credits_used: Union[Unset, float] = 0.0
    build_args: Union[Unset, Any] = UNSET
    shared_users: Union[Unset, List[SharedUsers]] = UNSET
    history: Union[Unset, List[AccessHistory]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        deployment_id = self.deployment_id
        deployment_name = self.deployment_name
        owner = self.owner
        repo_name = self.repo_name
        account_type = self.account_type
        repo_owner = self.repo_owner
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        branch_release = self.branch_release
        current_state = self.current_state
        visibility = self.visibility
        is_dev_env = self.is_dev_env
        creation_time = self.creation_time
        sha = self.sha
        owner_login = self.owner_login
        is_deleted = self.is_deleted
        instance: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.instance, Unset):
            instance = self.instance.to_dict()

        pcr_codes: Union[Unset, List[str]] = UNSET
        if not isinstance(self.pcr_codes, Unset):
            pcr_codes = self.pcr_codes

        credit_utilization_per_hour = self.credit_utilization_per_hour
        total_credits_used = self.total_credits_used
        build_args = self.build_args
        shared_users: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.shared_users, Unset):
            shared_users = []
            for shared_users_item_data in self.shared_users:
                shared_users_item = shared_users_item_data.to_dict()

                shared_users.append(shared_users_item)

        history: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.history, Unset):
            history = []
            for history_item_data in self.history:
                history_item = history_item_data.to_dict()

                history.append(history_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if deployment_id is not UNSET:
            field_dict["deployment_id"] = deployment_id
        if deployment_name is not UNSET:
            field_dict["deployment_name"] = deployment_name
        if owner is not UNSET:
            field_dict["owner"] = owner
        if repo_name is not UNSET:
            field_dict["repo_name"] = repo_name
        if account_type is not UNSET:
            field_dict["account_type"] = account_type
        if repo_owner is not UNSET:
            field_dict["repo_owner"] = repo_owner
        if tags is not UNSET:
            field_dict["tags"] = tags
        if branch_release is not UNSET:
            field_dict["branch_release"] = branch_release
        if current_state is not UNSET:
            field_dict["current_state"] = current_state
        if visibility is not UNSET:
            field_dict["visibility"] = visibility
        if is_dev_env is not UNSET:
            field_dict["is_dev_env"] = is_dev_env
        if creation_time is not UNSET:
            field_dict["creation_time"] = creation_time
        if sha is not UNSET:
            field_dict["sha"] = sha
        if owner_login is not UNSET:
            field_dict["owner_login"] = owner_login
        if is_deleted is not UNSET:
            field_dict["is_deleted"] = is_deleted
        if instance is not UNSET:
            field_dict["instance"] = instance
        if pcr_codes is not UNSET:
            field_dict["pcr_codes"] = pcr_codes
        if credit_utilization_per_hour is not UNSET:
            field_dict["credit_utilization_per_hour"] = credit_utilization_per_hour
        if total_credits_used is not UNSET:
            field_dict["total_credits_used"] = total_credits_used
        if build_args is not UNSET:
            field_dict["build_args"] = build_args
        if shared_users is not UNSET:
            field_dict["shared_users"] = shared_users
        if history is not UNSET:
            field_dict["history"] = history

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        deployment_id = d.pop("deployment_id", UNSET)

        deployment_name = d.pop("deployment_name", UNSET)

        owner = d.pop("owner", UNSET)

        repo_name = d.pop("repo_name", UNSET)

        account_type = d.pop("account_type", UNSET)

        repo_owner = d.pop("repo_owner", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        branch_release = d.pop("branch_release", UNSET)

        current_state = d.pop("current_state", UNSET)

        visibility = d.pop("visibility", UNSET)

        is_dev_env = d.pop("is_dev_env", UNSET)

        creation_time = d.pop("creation_time", UNSET)

        sha = d.pop("sha", UNSET)

        owner_login = d.pop("owner_login", UNSET)

        is_deleted = d.pop("is_deleted", UNSET)

        _instance = d.pop("instance", UNSET)
        instance: Union[Unset, Instance]
        if isinstance(_instance, Unset):
            instance = UNSET
        else:
            instance = Instance.from_dict(_instance)

        pcr_codes = cast(List[str], d.pop("pcr_codes", UNSET))

        credit_utilization_per_hour = d.pop("credit_utilization_per_hour", UNSET)

        total_credits_used = d.pop("total_credits_used", UNSET)

        build_args = d.pop("build_args", UNSET)

        shared_users = []
        _shared_users = d.pop("shared_users", UNSET)
        for shared_users_item_data in _shared_users or []:
            shared_users_item = SharedUsers.from_dict(shared_users_item_data)

            shared_users.append(shared_users_item)

        history = []
        _history = d.pop("history", UNSET)
        for history_item_data in _history or []:
            history_item = AccessHistory.from_dict(history_item_data)

            history.append(history_item)

        deployment_complete = cls(
            deployment_id=deployment_id,
            deployment_name=deployment_name,
            owner=owner,
            repo_name=repo_name,
            account_type=account_type,
            repo_owner=repo_owner,
            tags=tags,
            branch_release=branch_release,
            current_state=current_state,
            visibility=visibility,
            is_dev_env=is_dev_env,
            creation_time=creation_time,
            sha=sha,
            owner_login=owner_login,
            is_deleted=is_deleted,
            instance=instance,
            pcr_codes=pcr_codes,
            credit_utilization_per_hour=credit_utilization_per_hour,
            total_credits_used=total_credits_used,
            build_args=build_args,
            shared_users=shared_users,
            history=history,
        )

        deployment_complete.additional_properties = d
        return deployment_complete

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



USER_ID = "user_id"
USER_LOGIN = "user_login"
USER_TOKEN = "user_token"
USER_EMAIL = "user_email"
USER_NAME = "user_name"
BAD_REQUEST_MESSAGE = "Bad Request"
API_GW_REQUEST_ID = "dummy-request-id"
EXCEPTION_OCCURED = "Exception Occured"
FORBIDDEN = "Forbidden"
SUCCESS="Success"
KEY_MESSAGE = "message"
KEY_APIGW_REQUESTID = "apigw-requestid"
KEY_VALID_ERROR_LOC = "location"
VALID_ERROR_MESSAGE = "Invalid Message"
VALID_ERROR_VALUE = "value"
GITHUB_USER_ID = "123456"
GITHUB_USER_LOGIN = "github_user_login"
OLD_PASS="Oldpass123#"
NEW_PASS="Newpass123#"
GITHUB = "github"
RANDOM_PUBLIC_KEY = "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnLMkUkUTDrI2QIkyzF9iULdvjzpJHDIjV1r9X1R9D4wbzpC8cmwblSOD9gS9iZQaEijBzlc1gbe3fXMhwM6XImVQ7xn1lfQ7WZcfwTLK+V1lqIBIqn/Y+hxhecbWKM25RIRoAJ/jIfL608ltydbsl0oaMaEnU1r5PwNh5vGp8vVPsEN0DwgyJjrA6qTv1ZqeSoPuNwcQJH07U9tRngIABf5mKzUfRphX011CqISgKh8drwtac7nRxL452fD5eErRVTa6vrTfvKV5H4SUM3uJIuLE718xEM0QRaWfSSBD2hPCbpCSqaaAUFGgI3oEJ7LbA3z3pGmcKAUTVIwIDAQAB"
INVALID_PUBLIC_KEY = "MIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEf452fD5eErRVTa6vrTfvKV5H4SUM3uJIuLE718xEM0QRaWfSSBD2hPCbpCSqaaAUFGgI3oEJ7LbA3z3pGmcKAUTVIwIDAQAB"
USER_REPO = {
    "repo_id": 123456,
    "name": "Repo_Name",
    "is_private": False,
    "owner_login": "Owner_Login",
    "account_type": "github"
}
VCS_REPO_RESPONSE = {
    "repos": [{
        "repo_id": 506983974,
        "name": "Oblivious",
        "full_name": "ObliviousAI/Oblivious",
        "is_private": False,
        "owner_login": "ObliviousAI",
        "description": "\u2728 A single place to post issues & feature requests",
        "html_url": "https://github.com/ObliviousAI/Oblivious",
        "git_url": "git://github.com/ObliviousAI/Oblivious.git",
        "clone_url": "https://github.com/ObliviousAI/Oblivious.git",
        "default_branch": "master",
        "updated_at": "2022-09-01T20:29:36Z",
        "account_type": "github"
    },
        {
        "repo_id": 123456,
        "name": "Repo_Name",
                "full_name": "Owner_Login/Repo_Name",
                "is_private": False,
                "owner_login": "Owner_Login",
                "account_type": "github",
        "description": "Some Description",
        "html_url": "https://github.com/Owner_Login/Repo_Name",
        "git_url": "git://github.com/Owner_Login/Repo_Name.git",
        "clone_url": "https://github.com/Owner_Login/Repo_Name.git",
        "default_branch": "master",
        "updated_at": "2022-09-12T20:29:36Z",
        "account_type": "github"
    }],
  "total_pages": 1,
  "message": ""
}
REPO_WITH_SERVICE={
        "repo_id": 123456,
        "name": "Repo_Name",
                "full_name": "Owner_Login/Repo_Name",
                "is_private": False,
                "owner_login": "Owner_Login",
                "account_type": "github",
        "description": "Some Description",
        "html_url": "https://github.com/Owner_Login/Repo_Name",
        "git_url": "git://github.com/Owner_Login/Repo_Name.git",
        "clone_url": "https://github.com/Owner_Login/Repo_Name.git",
        "default_branch": "master",
        "updated_at": "2022-09-12T20:29:36Z",
        "account_type": "github",
        "services": [{
            "ref": "master",
            "sha": "some sha",
            "type": "branch",
            "service_validated": True
        }]
    }

REPO_REFS={"branch":["master","dummy"],"tags":["v1.0"]}
USER_SERVICES = [{
    "repo_id": "123456",
    "repo_name": "Repo_Name",
    "repo_owner": "Owner_Name",
    "account_type": "github",
    "ref": "master",
    "sha": "some sha",
    "type": "branch",
    "service_validated": True
}]
REPO_SERVICES = [{
    "ref": "master",
    "sha": "some sha",
    "type": "branch",
    "service_validated": True
}]
SERVICE_YAML_CONTENT={
  "auth": [
    {
      "auth_name": "Auth",
      "auth_type": "signed_headers"
    }
  ],
  "base_image": "oblv_ubuntu_18_04_proxy_nsm_api_python_3_8",
  "build_args": [],
  "meta": {
    "author": "Team Oblivious",
    "author_email": "hello@oblivious.ai",
    "git": "https://github.com/ObliviousAI/FastAPI-Enclave-Services.git",
    "version": "0.1.0"
  },
  "paths": [
    {
      "access": "user",
      "path": "/hello/",
      "short_description": "Hello world example"
    }
    ],
    "outbound": [
      {
        "domain": "example.com",
        "name": "example",
        "port": 443,
        "type": "tcp"
      }
    ]
  }
DEPLOYMENT_ID="deployment_id"
DEPLOYMENT={
    "deployment_id": DEPLOYMENT_ID,
    "deployment_name": "deployment_name",
    "account_type": "github",
    "owner": USER_ID,
    "owner_login": USER_LOGIN,
    "repo_name": "Repo_Name",
    "repo_owner": "Owner_Name",
    "tags": [],
    "branch_release": "master",
    "current_state": "Running",
    "visibility": "private",
    "is_dev_env": True,
    "creation_time": "01-06-2022 19:50:02",
    "sha": "some sha",
    "is_deleted": True,
    "instance": {
        "region_name": "us-east-1",
        "stack_name": "stack name",
        "instance_type": "c5.xlarge",
        "instance_url": "instance url",
        "service_url": "service url",
        "build_log_location": ""
    },
    "pcr_codes": ["pcr0codeletters","pcr1codeletters","pcr2codeletters"],
    "credit_utilization_per_hour": 68,
    "build_args": {
        "auth": {},
        "users": {
            "user": [{
                "user_name": "some_user",
                "public key": "MIIBCgKCAQEA1MuTZlPrs845FZOFm8TTeakJKr1FmW3JxAc64IafZw3WYvP1wtQOH4eSgJm5138RG1Hdg4gmWkS/4PbstxTpciwX80ARKbi8Jv7UkayeKBeLT7j7B+aRxebIJUH0THstST9nFO+10MTuNY7+AXNzfYR6PihtfmQIDAQAA",
                "user_login": "u-185b6de2-837a-4cbb-93fc-d1c9f96f3b04"
            }]
        },
        "infra_reqs": {
            "CPUs": 2,
            "RAM": 4000
        }
    },
    "shared_users": [],
    "history": [{
        "action": "STARTED",
        "timestamp": "01-06-2022 19:55:42"
    }]
}
SUPPORTED_REGIONS={
  "us-east-1": "US East (N. Virginia)",
  "us-west-2": "US West (Oregon)",
  "eu-central-1": "Europe (Frankfurt)",
  "eu-west-2": "Europe (London)"
}
DEPLOYMENT_ROLES=[{
    "role_name": "user",
    "role_description": "User Role"
}]
ARGUMENTS_RESPONSE={
  "sha": "some_sha",
  "arg_schema": {
    "some_key": "some_value"
  }
}
CREATE_DEPLOYMENT_INPUT= {
    "owner": "Owner Name",
    "repo": "Repo Name",
    "account_type": "github",
    "ref": "master",
    "ref_type": "branch",
    "region_name": "us-east-2",
    "deployment_name": "deployment name",
    "visibility": "private",
    "is_dev_env": True,
    "tags": [],
    "build_args": {
        "auth": {},
        "users": {
            "user": [{
                "user_name": "some_user",
                "public key": "MIIBCgKCAQEA1MuTZlPrs845FZOFm8TTeakJKr1FmW3JxAc64IafZw3WYvP1wtQOH4eSgJm5138RG1Hdg4gmWkS/4PbstxTpciwX80ARKbi8Jv7UkayeKBeLT7j7B+aRxebIJUH0THstST9nFO+10MTuNY7+AXNzfYR6PihtfmQIDAQAA",
                "user_login": "u-185b6de2-837a-4cbb-93fc-d1c9f96f3b04"
            }]
        },
        "infra_reqs":"c5.xlarge"
    }
}



""" Contains all the data models used in inputs/outputs """

from .access_history import AccessHistory
from .account import Account
from .api_key import APIKey
from .build_args_schema import BuildArgsSchema
from .create_deployment_input import CreateDeploymentInput
from .create_deployment_response import CreateDeploymentResponse
from .deployment_complete import DeploymentComplete
from .deployment_response import DeploymentResponse
from .http_validation_error import HTTPValidationError
from .instance import Instance
from .message_model import MessageModel
from .name_input import NameInput
from .notification_response import NotificationResponse
from .oblv_auth_response import OblvAuthResponse
from .psk import PSK
from .ref_response import RefResponse
from .repo import Repo
from .repo_all_response import RepoAllResponse
from .repo_services import RepoServices
from .role_response import RoleResponse
from .service_content_response import ServiceContentResponse
from .service_validation_response import ServiceValidationResponse
from .service_yaml_add_input import ServiceYamlAddInput
from .service_yaml_update_input import ServiceYamlUpdateInput
from .shared_users import SharedUsers
from .user_credit_utilization import UserCreditUtilization
from .user_password_input import UserPasswordInput
from .user_profile_response import UserProfileResponse
from .user_services import UserServices
from .validated_service import ValidatedService
from .validation_error import ValidationError
from .vcs_repo_response import VCSRepoResponse



import os

from rich.console import Console

from oblv_ctl import OblvClient

cred_file_path = os.path.join(os.path.expanduser('~'),'.oblv','credentials')

console = Console()

def read_credentials():
    with open(cred_file_path,'r') as f:
        contents = f.read()
        contents = contents.split("\n")
        for c in range(2):
            contents[c]=contents[c].split(" = ")
        client = OblvClient(oblivious_user_id=contents[0][1],token=contents[1][1])
    return client


def render_output(object):
    if type(object)==list:
        console.print_json(data=[x.to_dict() for x in object])
    else:
        print(object)



import pathlib

from setuptools import find_packages, setup

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name='oblv-ctl',
    version='0.3.0',
    description='A client library for accessing Oblivious APIs',
    author='Oblivious Support',
    author_email='support@oblivious.ai',
    license='Apache-2.0',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/ObliviousAI/oblv-ctl',
    keywords=['Oblivious', 'python', 'package'],
    packages=find_packages(),
    install_requires=[
        'httpx==0.15.0',
        'python-dateutil==2.8.0',
        'typer==0.7.0',
        'rich==13.3.4',
        'requests==2.29.0',
        'check-jsonschema==0.22.0',
    ],
    entry_points={
        'console_scripts': [
            'oblv-ctl=oblv_ctl.cli.main:app',
        ],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    package_data={"oblv_ctl": ["py.typed"]},
)


import imp
import unittest
from http.client import FORBIDDEN
from unittest.mock import patch

from httpx import Response

from oblv_ctl.exceptions import (BadRequestError, HTTPClientError,
                             ParamValidationError, UnauthorizedTokenError)
from oblv_ctl.models.account import Account
from oblv_ctl.models.http_validation_error import HTTPValidationError
from oblv_ctl.models.validation_error import ValidationError
from oblv_ctl.oblv_client import OblvClient
from tests.unit.constants import (API_GW_REQUEST_ID, BAD_REQUEST_MESSAGE,
                                  DEPLOYMENT, EXCEPTION_OCCURED, GITHUB,
                                  GITHUB_USER_ID, GITHUB_USER_LOGIN,
                                  KEY_APIGW_REQUESTID, KEY_MESSAGE,
                                  KEY_VALID_ERROR_LOC, SUPPORTED_REGIONS,
                                  USER_ID, USER_TOKEN, VALID_ERROR_MESSAGE,
                                  VALID_ERROR_VALUE)


class TestSupportedAWSRegions(unittest.TestCase):

    client = OblvClient(token=USER_TOKEN, oblivious_user_id=USER_ID)

    def setUp(self) -> None:
        super().setUp()
        
    def getForbiddenResponse():
        res = Response(403, json=FORBIDDEN)
        return res

    def getSuccessResponse():
        res = Response(200, json=SUPPORTED_REGIONS)
        return res
    
    @patch("httpx.request", return_value=getForbiddenResponse())
    def test_bad_authentication_request(self, sync):
        with self.assertRaises(UnauthorizedTokenError):
            self.client.supported_aws_regions()

    @patch("httpx.request", return_value=getSuccessResponse())
    def test_success_request(self, sync):
        self.assertEqual(self.client.supported_aws_regions().to_dict(), SUPPORTED_REGIONS)


if __name__ == '__main__':
    unittest.main()
